@@ -385,7 +385,15 @@ sub draw_one_cell_table {
 
 	draw_table (
 	
-		['', {label => '', off => 0}, ''],
+		[
+			'', 
+			{
+				label => '', 
+				off => 0, 
+				href => 'javaScript:alert("Joke!")'
+			}, 
+			''
+		],
 		
 		sub {		
 			draw_text_cell ({label => $i -> {id}}) . 
@@ -881,6 +889,10 @@ sub draw_form_field_hgroup {
 
  .   60.
 
+=item value
+
+  .
+
 =back
 
 =cut
